@@ -22,5 +22,6 @@
    Authors: Alexander Larsson <alexl@redhat.com>
 */
 
-int make_iso (const char *filename, const char *label, gboolean warn_low_space);
+int make_iso (const char *filename, const char *label,
+		gboolean warn_low_space, gboolean use_joliet);
 GList *build_list_of_audio_tracks (void);
